jacinle.config.environ\_v2
==========================

.. automodule:: jacinle.config.environ_v2

   
   
   .. rubric:: Module attributes

   .. autosummary::
   
      configs
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      StrictG
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      def_configs
      def_configs_func
      set_configs
      set_configs_func
   
   

   
   
   








.. rubric:: Class StrictG
.. autoclass:: StrictG
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: def_configs

.. autofunction:: def_configs_func

.. autofunction:: set_configs

.. autofunction:: set_configs_func


